==> igniteui-angular-charts-17.0.0-beta.0.tgz: package/esm2015/lib/CategoryChartToolbarProvider.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { DomainChartToolbarProvider } from "./DomainChartToolbarProvider";
import { markType } from "igniteui-angular-core";
/**
 * @hidden
 */
export let CategoryChartToolbarProvider = /*@__PURE__*/ (() => {
    class CategoryChartToolbarProvider extends DomainChartToolbarProvider {
        constructor() {
            super(...arguments);
            this.y = null;
        }
        e(a, b) {
            let c = a;
            switch (b.name) {
                case "ShowGridlines":
                    {
                        let d = b;
                        d.isChecked = c.ace != null;
                    }
                    break;
            }
        }
        u(a, b, c, d) {
            let e = a;
            switch (b) {
                case "XAxisMajorStroke":
                    this.f("ShowGridlines", 2, a.ace != null);
                    break;
            }
        }
        k(a, b) {
            let c = a;
            if (this.c(b, "ShowGridlines")) {
                if (c.ace == null) {
                    if (this.y != null) {
                        c.ace = this.y;
                    }
                    else {
                        c.ace = c.dataChart.x4;
                    }
                }
            }
            else {
                if (c.ace != null) {
                    this.y = c.ace;
                    c.ace = null;
                }
            }
        }
    }
    CategoryChartToolbarProvider.$t = markType(CategoryChartToolbarProvider, 'CategoryChartToolbarProvider', DomainChartToolbarProvider.$);
    return CategoryChartToolbarProvider;
})();

==> igniteui-angular-charts-17.2.0-beta.0.tgz: package/esm2015/lib/CategoryChartToolbarProvider.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { DomainChartToolbarProvider } from "./DomainChartToolbarProvider";
import { markType } from "igniteui-angular-core";
/**
 * @hidden
 */
export let CategoryChartToolbarProvider = /*@__PURE__*/ (() => {
    class CategoryChartToolbarProvider extends DomainChartToolbarProvider {
        constructor() {
            super(...arguments);
            this.y = null;
        }
        e(a, b) {
            let c = a;
            switch (b.name) {
                case "ShowGridlines":
                    {
                        let d = b;
                        d.isChecked = c.acw != null;
                    }
                    break;
            }
        }
        u(a, b, c, d) {
            let e = a;
            switch (b) {
                case "XAxisMajorStroke":
                    this.f("ShowGridlines", 2, a.acw != null);
                    break;
            }
        }
        k(a, b) {
            let c = a;
            if (this.c(b, "ShowGridlines")) {
                if (c.acw == null) {
                    if (this.y != null) {
                        c.acw = this.y;
                    }
                    else {
                        c.acw = c.dataChart.x8;
                    }
                }
            }
            else {
                if (c.acw != null) {
                    this.y = c.acw;
                    c.acw = null;
                }
            }
        }
    }
    CategoryChartToolbarProvider.$t = markType(CategoryChartToolbarProvider, 'CategoryChartToolbarProvider', DomainChartToolbarProvider.$);
    return CategoryChartToolbarProvider;
})();
